==> webgui_7.7.30.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Account_Shop.pm <==
package WebGUI::i18n::English::Account_Shop;
use strict;

our $I18N = {

    'title' => {
        message     => q{Shop},
        lastUpdated => 1225724810,
        context     => q{Tab label for User Account pluggin},
    },

    'shop style template label' => {
        message     => q|Style Template|,
        lastUpdated => 1119068809,
	},

    'shop style template hoverHelp' => {
        message     => q|Select a style template from the list to enclose the shop tab in.|,
        lastUpdated => 1119068809,
	},

    'shop layout template label' => {
        message     => q|Layout Template|,
        lastUpdated => 1119068809,
	},

    'shop layout template hoverHelp' => {
        message     => q{Choose a layout template in which to enclose the content from the various methods within the shop tab},
        lastUpdated => 1119068809,
    },

    'manage purchases label' => {
        message     => q{Manage Purchases},
        lastUpdated => 1119068809,
    },

    'manage_purchases_url' => {
        message     => q{The URL to the manage purchases screen.},
        lastUpdated => 1119068809,
    },

    'managePurchasesIsActive' => {
        message     => q{A boolean that is true if the current screen is view, managePurchases or viewTransaction.},
        lastUpdated => 1119068809,
    },

    'common account variables' => {
        message     => q{Common Account, Shop Plugin, Template Variables.},
        lastUpdated => 1230867169,
    },

    'my sales label' => {
        message     => q{Sales},
        lastUpdated => 0,
    },

    'manage tax label' => {
        message     => q{Manage Tax Settings},
        lastUpdated => 0,
        context     => q{Label for the manage tax tab},
    },

    'my sales template' => {
        message     => q{My Sales Template},
        lastUpdated => 0,
        context     => q{Template for displaying My Sales},
    },

    'my sales template help' => {
        message     => q{Template to render the screen where vendor sales are displayed.},
        lastUpdated => 0,
        context     => q{hoverhelp for settings},
    },

    'Payout Totals' => {
        message     => q{Payout Totals},
        lastUpdated => 0,
        context     => q{Similar to Total amount paid.},
    },

    'Paid' => {
        message     => q{Paid},
        lastUpdated => 0,
        context     => q{},
    },

    'Scheduled for payment' => {
        message     => q{Scheduled for payment},
        lastUpdated => 0,
        context     => q{},
    },

    'Not yet scheduled' => {
        message     => q{Not yet scheduled},
        lastUpdated => 0,
        context     => q{},
    },

    'Product' => {
        message     => q{Product},
        lastUpdated => 0,
        context     => q{},
    },

    'Products' => {
        message     => q{Products},
        lastUpdated => 0,
        context     => q{},
    },

    'Payout' => {
        message     => q{Payout},
        lastUpdated => 0,
        context     => q{},
    },

};

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Account_Shop.pm <==
package WebGUI::i18n::English::Account_Shop;
use strict;

our $I18N = {

    'title' => {
        message     => q{Shop},
        lastUpdated => 1225724810,
        context     => q{Tab label for User Account pluggin},
    },

    'shop style template label' => {
        message     => q|Style Template|,
        lastUpdated => 1119068809,
	},

    'shop style template hoverHelp' => {
        message     => q|Select a style template from the list to enclose the shop tab in.|,
        lastUpdated => 1119068809,
	},

    'shop layout template label' => {
        message     => q|Layout Template|,
        lastUpdated => 1119068809,
	},

    'shop layout template hoverHelp' => {
        message     => q{Choose a layout template in which to enclose the content from the various methods within the shop tab},
        lastUpdated => 1119068809,
    },

    'manage purchases label' => {
        message     => q{Manage Purchases},
        lastUpdated => 1119068809,
    },

    'manage_purchases_url' => {
        message     => q{The URL to the manage purchases screen.},
        lastUpdated => 1119068809,
    },

    'managePurchasesIsActive' => {
        message     => q{A boolean that is true if the current screen is view, managePurchases or viewTransaction.},
        lastUpdated => 1119068809,
    },

    'userIsVendor' => {
        message     => q{A boolean that is true if the current user is a vendor.},
        lastUpdated => 1263833421,
    },

    'common account variables' => {
        message     => q{Common Account, Shop Plugin, Template Variables.},
        lastUpdated => 1230867169,
    },

    'my sales label' => {
        message     => q{Sales},
        lastUpdated => 0,
    },

    'manage tax label' => {
        message     => q{Manage Tax Settings},
        lastUpdated => 0,
        context     => q{Label for the manage tax tab},
    },

    'my sales template' => {
        message     => q{My Sales Template},
        lastUpdated => 0,
        context     => q{Template for displaying My Sales},
    },

    'my sales template help' => {
        message     => q{Template to render the screen where vendor sales are displayed.},
        lastUpdated => 0,
        context     => q{hoverhelp for settings},
    },

    'Payout Totals' => {
        message     => q{Payout Totals},
        lastUpdated => 0,
        context     => q{Similar to Total amount paid.},
    },

    'Paid' => {
        message     => q{Paid},
        lastUpdated => 0,
        context     => q{},
    },

    'Scheduled for payment' => {
        message     => q{Scheduled for payment},
        lastUpdated => 0,
        context     => q{},
    },

    'Not yet scheduled' => {
        message     => q{Not yet scheduled},
        lastUpdated => 0,
        context     => q{},
    },

    'Product' => {
        message     => q{Product},
        lastUpdated => 0,
        context     => q{},
    },

    'Products' => {
        message     => q{Products},
        lastUpdated => 0,
        context     => q{},
    },

    'Payout' => {
        message     => q{Payout},
        lastUpdated => 0,
        context     => q{},
    },

};

1;
